@@ -1,4 +1,3 @@
-import sys
 from typing import Any, List
 
 from erdpy import cli_shared, validators, utils
@@ -104,10 +103,7 @@ def do_stake(args: Any):
     validators.prepare_args_for_stake(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unstake(args: Any):
@@ -116,10 +112,7 @@ def do_unstake(args: Any):
     validators.prepare_args_for_unstake(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unjail(args: Any):
@@ -128,10 +121,7 @@ def do_unjail(args: Any):
     validators.prepare_args_for_unjail(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unbond(args: Any):
@@ -140,10 +130,7 @@ def do_unbond(args: Any):
     validators.prepare_args_for_unbond(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def change_reward_address(args: Any):
@@ -152,10 +139,7 @@ def change_reward_address(args: Any):
     validators.prepare_args_for_change_reward_address(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_claim(args: Any):
@@ -164,10 +148,7 @@ def do_claim(args: Any):
     validators.prepare_args_for_claim(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unstake_nodes(args: Any):
@@ -176,10 +157,7 @@ def do_unstake_nodes(args: Any):
     validators.prepare_args_for_unstake_nodes(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unstake_tokens(args: Any):
@@ -188,10 +166,7 @@ def do_unstake_tokens(args: Any):
     validators.prepare_args_for_unstake_tokens(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unbond_nodes(args: Any):
@@ -200,10 +175,7 @@ def do_unbond_nodes(args: Any):
     validators.prepare_args_for_unbond_nodes(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_unbond_tokens(args: Any):
@@ -212,10 +184,7 @@ def do_unbond_tokens(args: Any):
     validators.prepare_args_for_unbond_tokens(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_clean_registered_data(args: Any):
@@ -224,10 +193,7 @@ def do_clean_registered_data(args: Any):
     validators.prepare_args_for_clean_registered_data(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
 
 
 def do_restake_unstaked_nodes(args: Any):
@@ -236,7 +202,4 @@ def do_restake_unstaked_nodes(args: Any):
     validators.prepare_args_for_restake_unstaked_nodes(args)
     tx = do_prepare_transaction(args)
 
-    try:
-        cli_shared.send_or_simulate(tx, args)
-    finally:
-        tx.dump_to(args.outfile)
+    cli_shared.send_or_simulate(tx, args)
