@@ -1,6 +1,6 @@
 import base64
 import logging
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Tuple
 
 from Cryptodome.Hash import keccak
 
@@ -12,7 +12,11 @@ from erdpy.utils import Object
 
 logger = logging.getLogger("contracts")
 
-HEX_PREFIX = "0X"
+HEX_PREFIX = "0x"
+ERD_BECH32_PREFIX = "erd"
+FALSE_STR_LOWER = "false"
+TRUE_STR_LOWER = "true"
+STR_PREFIX = "str:"
 
 
 class QueryResult(Object):
@@ -52,7 +56,7 @@ class SmartContract:
         return tx
 
     def prepare_deploy_transaction_data(self, arguments: List[Any]):
-        tx_data = f"{self.bytecode}@{constants.VM_TYPE_ARWEN}@{self.metadata.to_hex()}"
+        tx_data = f"{self.bytecode}@{constants.VM_TYPE_WASM_VM}@{self.metadata.to_hex()}"
 
         for arg in arguments:
             tx_data += f"@{_prepare_argument(arg)}"
@@ -177,17 +181,38 @@ class SmartContract:
 
 
 def _prepare_argument(argument: Any):
-    as_string = str(argument).upper()
+    as_str = str(argument)
+    as_hex = _to_hex(as_str)
+    return as_hex
 
-    if as_string.startswith(HEX_PREFIX):
-        return _prepare_hexadecimal(as_string)
 
-    return _prepare_decimal(as_string)
+def _to_hex(arg: str):
+    if arg.startswith(HEX_PREFIX):
+        return _prepare_hexadecimal(arg)
+
+    if arg.isnumeric():
+        return _prepare_decimal(arg)
+    elif arg.startswith(ERD_BECH32_PREFIX):
+        addr = Address(arg)
+        return _prepare_hexadecimal(f"{HEX_PREFIX}{addr.hex()}")
+    elif arg.lower() == FALSE_STR_LOWER or arg.lower() == TRUE_STR_LOWER:
+        as_str = f"{HEX_PREFIX}01" if arg.lower() == TRUE_STR_LOWER else f"{HEX_PREFIX}00"
+        return _prepare_hexadecimal(as_str)
+    elif arg.startswith(STR_PREFIX):
+        as_hex = f"{HEX_PREFIX}{arg[len(STR_PREFIX):].encode('ascii').hex()}"
+        return _prepare_hexadecimal(as_hex)
+    else:
+        raise Exception(f"could not convert {arg} to hex")
 
 
 def _prepare_hexadecimal(argument: str) -> str:
     argument = argument[len(HEX_PREFIX):]
+    argument = argument.upper()
     argument = ensure_even_length(argument)
+
+    if argument == "":
+        return ""
+
     try:
         _ = int(argument, 16)
     except ValueError:
@@ -202,7 +227,7 @@ def _prepare_decimal(argument: str) -> str:
     as_number = int(argument)
     as_hexstring = hex(as_number)[len(HEX_PREFIX):]
     as_hexstring = ensure_even_length(as_hexstring)
-    return as_hexstring
+    return as_hexstring.upper()
 
 
 def ensure_even_length(string: str) -> str:
@@ -211,10 +236,27 @@ def ensure_even_length(string: str) -> str:
     return string
 
 
+def sum_flag_values(flag_value_pairs: List[Tuple[int, bool]]) -> int:
+    value_sum = 0
+    for value, flag in flag_value_pairs:
+        if flag:
+            value_sum += value
+    return value_sum
+
+
 class CodeMetadata:
-    def __init__(self, upgradeable: bool = True, payable: bool = False):
+    def __init__(self, upgradeable: bool = True, readable: bool = True, payable: bool = False, payable_by_sc: bool = False):
         self.upgradeable = upgradeable
+        self.readable = readable
         self.payable = payable
+        self.payable_by_sc = payable_by_sc
 
     def to_hex(self):
-        return ("01" if self.upgradeable else "00") + ("02" if self.payable else "00")
+        flag_value_pairs = [
+            (0x01_00, self.upgradeable),
+            (0x04_00, self.readable),
+            (0x00_02, self.payable),
+            (0x00_04, self.payable_by_sc)
+        ]
+        metadata_value = sum_flag_values(flag_value_pairs)
+        return f"{metadata_value:04X}"
