@@ -210,6 +210,10 @@ class TemplateRust(Template):
                 (f"<{template_name}::AbiProvider>()", f"<{project_name}::AbiProvider>()"),
                 # Example: replace "extern crate adder;" to "extern crate myadder;"
                 (f"extern crate {template_name};", f"extern crate {project_name};"),
+                # Example: replace "empty::ContractObj" to "foo_bar::ContractObj"
+                (f"{template_name}::ContractObj", f"{project_name}::ContractObj"),
+                (f"{template_name}::ContractBuilder", f"{project_name}::ContractBuilder"),
+                (f"{template_name}::contract_obj", f"{project_name}::contract_obj"),
             ],
             ignore_missing
         )
