@@ -56,19 +56,19 @@ def test_merge_configs():
 def test_init():
     data = dict()
     data['folders'] = {
-        'elrond_go': '{ELRONDSDK}/bar',
-        'elrond_proxy_go': '{ELRONDSDK}/foobar',
+        'mx_chain_go': '{ELRONDSDK}/bar',
+        'mx_chain_proxy_go': '{ELRONDSDK}/foobar',
         'testnet': '/some/where/mytestnet',
     }
 
     sdk_folder = workstation.get_tools_folder()
-    node_folder = erdpy.config.get_dependency_parent_directory('elrond_go')
+    node_folder = erdpy.config.get_dependency_parent_directory('mx_chain_go')
     (node_folder / 'v1.2.3').mkdir(parents=True, exist_ok=True)
 
-    proxy_folder = erdpy.config.get_dependency_parent_directory('elrond_proxy_go')
+    proxy_folder = erdpy.config.get_dependency_parent_directory('mx_chain_proxy_go')
     (proxy_folder / 'v2.3.4').mkdir(parents=True, exist_ok=True)
 
     testnet_config = config.TestnetConfiguration(data)
-    assert testnet_config.folders["elrond_go"] == sdk_folder / "bar"
-    assert testnet_config.folders["elrond_proxy_go"] == sdk_folder / "foobar"
+    assert testnet_config.folders["mx_chain_go"] == sdk_folder / "bar"
+    assert testnet_config.folders["mx_chain_proxy_go"] == sdk_folder / "foobar"
     assert testnet_config.folders["testnet"] == Path("/some/where/mytestnet")
